print("import: 'eolearn'")
import eolearn

print("import: 'eolearn.core'")
import eolearn.core

print("import: 'eolearn.mask'")
import eolearn.mask

